#!/bin/zsh

# basic functions
die() {
  echo "$*" >/dev/stderr
  exit 1
}
debug() { #change to false to disable debugging
  true && echo "$*" >>debug
}

# this program is supposed to be symlinked into a http root directory
# we will use the http root as object storage (data directory) and call sub
# programs from the directory in which the real executable resides
# therefore we need to identify the code and data directories _EXEC and _STOR
call=$0
real=$call
while [ -L "$real" ]; do
  real="$(stat -c %N "$real" |sed -r "s:..*. -> .(.*).$:\1:")"
done

_EXEC="$(dirname "$real")"  #execution directory
_STOR="$(dirname "$call")"  #storage directory

debug "Execution dir: $_EXEC"
debug "Storage dir: $_STOR"

[ -w "$_EXEC" ] && [ -d "$_EXEC" ] || die "storage directory must be writable"

# create directories for object storage
for each in "$_STOR"/{vcard,mappings,courses}; do
  [ ! -e "$each" ] && mkdir "$each"
  [ -w "$each" ] && [ -d "$each" ] || die "storage $each must be a writable directory"
done

# create htaccess file
[ -f .htaccess ] || cat >.htaccess <<EOF
Options		+ExecCGI
AddHandler	cgi-script .cgi
DirectoryIndex	index.cgi
EOF
[ -f .htaccess ] || die "no htaccess file present and unable to create one"

. "$_EXEC/cgi.sh"

cgi_get
debug "$_GET"

. "$_EXEC/page.sh"
